@@ -5,7 +5,7 @@ use parent 'Exporter';
 
 use XSLoader;
 
-our $VERSION = '0.000002';
+our $VERSION = '0.000003';
 XSLoader::load( __PACKAGE__, $VERSION );
 
 our @EXPORT_OK = qw[];
@@ -19,11 +19,12 @@ __END__
 
 =head1 NAME
 
-Parser::GraphQL::XS - Perl XS binding for the libgraphsql GraphSQL parsing library
+Parser::GraphQL::XS - Perl XS binding for libgraphqlparser, a GraphQL query
+parser in C++ with C and C++ APIs.
 
 =head1 VERSION
 
-Version 0.000002
+Version 0.000003
 
 =head1 SYNOPSIS
 
@@ -33,6 +34,12 @@ Version 0.000002
 
 =head1 SEE ALSO
 
+=over 4
+
+=item * L<< https://github.com/graphql/libgraphqlparser >>
+
+=back
+
 =head1 LICENSE
 
 Copyright (C) Gonzalo Diethelm.
